#!/bin/sh
#
# Copyright(C) 2003-2010 ALWIL Software.  All rights reserved.
#
# avast4server 3.2.1 installer
#

sys_prefix=""
usr_prefix="/usr"
var_prefix="/var"
if [ `uname -s` != "Linux" -a `uname -s` != "SunOS" ]; then usr_prefix="/usr/local" ; fi

sysdir="$sys_prefix/etc"
bindir="$usr_prefix/bin"
sbindir="$usr_prefix/sbin"
docdir="$usr_prefix/share/doc"
mandir="$usr_prefix/share/man";
if [ "$usr_prefix" = "/usr/local" ] && [ ! `uname -s` = "Linux" ]; then
    mandir="$usr_prefix/man";
fi

rundir="$var_prefix/run/avast4"
tempdir="$var_prefix/tmp/avast4"
logdir="$var_prefix/lib/avast4/log"

# Environment variables
PATH=.:/bin:/usr/bin:/usr/local/bin:/opt/bin:/opt/avast4/bin:/opt/avast4/sbin:/sbin:$PATH
export PATH

##############################
# Subroutines
##############################

platform="Linux"
architecture="i386"
osstyle="other"
# use own install instead of platform-incompatible install script
# for linking, use -l linkname target directory (don't use -m and -l together).
install()
{
    localchmod="no"
    localnonswitch="no"
    locallink="no"

    while [ $localnonswitch = "no" -a $# -ge 1 ]
	do
	    case $1 in
	        -m)	shift
	    		localchmod="$1"
			shift
			;;
		-l)	shift
			locallink="yes"
			locallinkname="$1"
			shift
			;;
		-*)  	echo "Install(): Unknown switch '$1' skipped."
			shift
			;;
		*)	localnonswitch="yes"
			;;
	    esac
	done

    if [ $# -eq 2 ]
      then
        if [ $locallink = "yes" ]
	    then
	        echo "Linking ${locallinkname}->$1 in $2."
	    	( cd $2; rm -f $locallinkname; ln -s $1 $locallinkname )
	    else
		echo "Installing $1 to $2."
		cp  $1 $2
	    fi
	if [ $localchmod != "no" ]
	  then
	    echo "Chmod $localchmod $2."
	    chmod $localchmod $2
	fi
    else
       echo "Install(): Not enough arguments."
   fi
}


# check user (must be root)
check_user()
{
	if [ `id | cut -d= -f2 | cut -d\( -f1` -ne 0 ]; then
		echo ""
		echo "This script must be run as root."
		echo " "
		exit 1
	fi
}

# check OS
check_os()
{
	platform=`uname -s`;
		
	case $platform in
	Linux)
	 ;;
	FreeBSD)
	 ;;
	SunOS)
	 ;;
	*)
		echo ""
		echo "Your operating system is not supported by the installer."
		echo " "
		exit 1
	 ;;
	esac

	#check os style
	if test -f /etc/init.d/functions
	then
		osstyle="rh"
	elif test -f /etc/init.d/functions.sh
	then
		osstyle="gentoo"
	elif test -f /etc/default/rcS
	then
		osstyle="debian"
	elif test -f /etc/rc.status
	then
		osstyle="suse"
	elif test -f /lib/lsb/init-functions
	then
		osstyle="lsb"
	elif test -f /etc/rc.d/rc.M
	then
		osstyle="slackware"
	elif test -d /etc/init.d -a -d /etc/rc2.d
	then
		osstyle="sysv"
	else
		osstyle="other"
	fi
}

# check architecture
check_architecture()
{
	architecture=`uname -m`
	case $architecture in
	  i86pc)
	  ;;
	  i[3456]86)
	   ;;
	  x86_64)
	   ;;
	  sun4u)
	    ;;
	  ppc)
	    ;;
	  *)
		echo ""
		echo "Your architecture ($architecture) is not supported"
		echo " "
		exit 1
	    ;;
	esac
}

# check avast! engine library
check_avastengine()
{
	libsolink=$1

	tmpvalue=0
	#look for shared library


    case $platform in
    Linux)
       tmpstr=`cat /etc/ld.so.conf`
       ;;
    FreeBSD)
       tmpstr=`cat /etc/defaults/rc.conf | grep -w "ldconfig_paths" | sed -e 's/[^\"]*\"\(.*\)\".*/\1/'`
       ;;
    SunOS)
       tmpstr=`crle | grep "Default Library Path" | cut -d: -f2- | sed s/:/\ /g`
       ;;
    esac
	
	for x in /usr/lib /usr/local/lib $tmpstr
	do
		[ -x $x/$libsolink ] && {
			tmpstring=`ls -l $x/$libsolink | sed -n 's/.*-> //p'`
			if [ -f $x/$tmpstring ]; then
				tmpvalue=1
			fi
			break;
		}
	done

	if [ $tmpvalue -eq 0 ]; then
		echo ""
		echo "avast! engine library '$libsolink' is not installed!"
		echo ""
		echo "Please donwload 'libavastengine-4.x.x-x.tar.gz' package"
		echo "and install it first!"
		echo " "
		exit 1
	fi
}

# agreements
get_installagreement() {
    printf "[ $1 ] "
    read localkey

    if [ -z "$localkey" ]; then
	tmpstring=$1
    else
	tmpstring=$localkey
    fi
}

get_yesnoagreement() {
    if [ $1 -eq 1 ]; then
	printf "[ yes ] "
    else
	printf "[ no ] "
    fi

    read localkey
    if [ -z "$key" ]; then
	tmpvalue=$1
    else
	case $localkey in
	y | Y | yes | Yes | YES | ok | Ok | OK )
		tmpvalue=1
		;;
	n | N | no | No | NO)
		tmpvalue=0
		;;
	*)
		tmpvalue=0
		;;
	esac
    fi
}


##############################
# Main Section
##############################

#check functions
check_user
check_os
check_architecture


progname=$0
version=3.2.1
packagename="avast4server"
packagevers="3.2.1"
instdir="`dirname "$0"`"

func_usage ()
{
    echo "Usage: $progname [OPTION...]"
    echo "Try '$progname --help' or '$progname -h' for more information."
}

func_help ()
{
    echo "Usage: $progname [OPTION...]"
    echo "$progname -- the avast! server for $platform installer"
    echo ""
    echo "Options:"
    echo "   -p=, --prefix=        Set installation path"
    echo "   -u, --uninstall       Uninstall previously installed version"
    echo "   -h, --help            Give this help list"
    echo "   -V, --version         Print program version"
    echo ""
    echo "Report bugs to <support@avast.com>."
}

func_version ()
{
    echo "$progname: the avast! server installer $version"
    echo "Copyright(C) 2005-2010. ALWIL Software. All rights reserved"
}

func_docheck ()
{
    echo "Checking for previous avast! server installation"

    check_installprefix="/"
    check_man1_avastcmddir=""
    check_man1_avastlitedir=""
    check_man5_avastdconfdir=""
    check_man8_avastddir=""
    check_bin_avastcmddir=""
    check_bin_avastlitedir=""
    check_bin_avastdwatchdir=""
    check_sbin_avastddir=""
    check_var_avast4tempdir=""
    check_var_avast4logdir=""

    #check for manual pages
    for x in $mandir `echo $MANPATH | sed 's/:/ /g'` /usr/local/share/man /usr/local/man /usr/share/man
    do
	[ -z "$check_man1_avastcmddir" ] && [ -f $x/man1/avastcmd.1 ] && {
	check_man1_avastcmddir=$x/man1;
	}
	[ -z "$check_man1_avastlitedir" ] && [ -f $x/man1/avastlite.1 ] && {
	check_man1_avastlitedir=$x/man1;
	}
	[ -z "$check_man5_avastdconfdir" ] && [ -f $x/man5/avastd.conf.5 ] && {
	check_man5_avastdconfdir=$x/man5;
	}
	[ -z "$check_man8_avastddir" ] && [ -f $x/man8/avastd.8 ] && {
	check_man8_avastddir=$x/man8;
	}
    done

    #check for binary files
    for x in $bindir $sbindir `echo $PATH | sed 's/:/ /g'`
    do
	[ -z "$check_bin_avastcmddir" ] && [ -f $x/avastcmd ] && {
	check_bin_avastcmddir=$x;
	}
	[ -z "$check_bin_avastlitedir" ] && [ -f $x/avastlite ] && {
	check_bin_avastlitedir=$x;
	}
	[ -z "$check_bin_avastdwatchdir" ] && [ -f $x/avastdwatch.sh ] && {
	check_bin_avastdwatchdir=$x;
	}
	[ -z "$check_sbin_avastddir" ] && [ -f $x/avastd ] && {
	check_sbin_avastddir=$x;
	}
    done

    check_var_avast4tempdir=$tempdir
    check_var_avast4logdir=$logdir

    #install prefix
    if [ ! -z "$check_bin_avastcmddir" ]; then
	pathname=`ls -l $check_bin_avastcmddir/avastcmd | sed -n 's/.*-> //p'`
	if [ -z "$pathname" ]; then pathname="$check_bin_avastcmddir/avastcmd"; fi
	checkpath=`echo $pathname | sed -e "s/\/bin\/avastcmd//"`
	if [ ! -z "$checkpath" ]; then check_installprefix=$checkpath; fi
    fi
    if [ $check_installprefix = "/" ]&&[ ! -z "$check_sbin_avastddir" ]; then
	pathname=`ls -l $check_sbin_avastddir/avastd | sed -n 's/.*-> //p'`
	if [ -z "$pathname" ]; then pathname="$check_sbin_avastddir/avastd"; fi
	checkpath=`echo $pathname | sed -e "s/\/sbin\/avastd//"`
	if [ ! -z "$checkpath" ]; then check_installprefix=$checkpath; fi
    fi
}


  get_agreement() {
    localres=1
    printf "[ yes / no ] "
    read localkey

    case $localkey in
    '') ;;
    [Yy][Ee][Ss]) ;;
    [Oo][Kk]) ;;
    [Yy]) ;;
    [Oo]) ;;
    *)
        localres=0
	;;
    esac
    return $localres;
  }


func_install ()
{
    ##################
    # Welcome user
    ##################
    echo ""
    echo ""
    echo "Copyright(C) 2003-2010 ALWIL Software.  All rights reserved."
    echo ""
    echo "$packagename for $platform will be installed on this machine."
    echo ""
    echo "Technical support is available at:"
    echo "http://www.avast.com/eng/support/technical_support.html"
    echo ""
    echo "To install 'avast!4' now, press ENTER."
    echo ""
    echo "To cancel the installation at any time, press Control-C."
    echo ""
    read cont < /dev/tty

    numproc=`ps -ef | grep avastd | grep -v "grep avastd" | wc -l`
    if [ ! $numproc -eq 0 ]
    then
	echo ""
	echo "A version of the avast! daemon appears to be running."
	echo " "
	echo "Please shut down any instance of the avast! you may have running"
	echo "before installing this version."
	echo " "
	exit 1
    fi

    if [ $platform = "Linux" -o $platform = "SunOS" ]; then
       libsolink="libavastengine-4.so.7"
    else
       libsolink="libavastengine-4.so"
    fi

    #check avastengine
    check_avastengine $libsolink

    #check for previous avast4server installation
    func_docheck
    echo ""
    previnstall=0;
    if [ ! -z "$check_bin_avastcmddir" ] ; then echo "found installed $check_bin_avastcmddir/avastcmd file" ; previnstall=1 ; fi
    if [ ! -z "$check_bin_avastlitedir" ] ; then echo "found installed $check_bin_avastlitedir/avastlite file" ; previnstall=1 ; fi
    if [ ! -z "$check_bin_avastdwatchdir" ] ; then echo "found installed $check_bin_avastdwatchdir/avastdwatch.sh file" ; previnstall=1 ; fi
    if [ ! -z "$check_sbin_avastddir" ] ; then echo "found installed $check_sbin_avastddir/avastd file" ; previnstall=1 ; fi

    if [ ! -z "$check_man1_avastcmddir" ] ; then echo "found installed $check_man1_avastcmddir/avastcmd.1 file" ; previnstall=1 ; fi
    if [ ! -z "$check_man1_avastlitedir" ] ; then echo "found installed $check_man1_avastlitedir/avastlite.1 file" ; previnstall=1 ; fi
    if [ ! -z "$check_man5_avastdconfdir" ] ; then echo "found installed $check_man5_avastdconfdir/avastd.conf.5 file" ; previnstall=1 ; fi
    if [ ! -z "$check_man8_avastddir" ] ; then echo "found installed $check_man8_avastddir/avastd.8 file" ; previnstall=1 ; fi

    if [ $previnstall -eq 1 ] ; then
	echo ""
        echo "Do you want to proceed with the installation?"
	get_agreement
        if [ $? -eq 0 ] ; then
	    echo ""
	    echo "To uninstall previously installed files type: $progname --uninstall"
	    echo " "
	    exit 1
        fi
    fi

    #committing installing paths
    echo ""
    echo "Do you want to install this package to the following directories:"
    echo "    configuration:    $sysdir"
    echo "    binary files to:  $bindir"
    echo "    daemon file to:   $sbindir"
    echo "    manual pages to:  $mandir"
    echo "    documentation to: $docdir"
    echo ""

    get_agreement
    if [ $? -eq 0 ] ; then 
      echo ""
      echo "Notice: you can use '--prefix' option to set another installation path";
      echo " "
      exit 1
    fi

    #installing executable files
    if [ ! -d $bindir ]; then mkdir -p $bindir ; fi
    install -m 755 "$instdir/bin/avastcmd" "$bindir/avastcmd"
    install -m 755 "$instdir/bin/avastlite" "$bindir/avastlite"
    install -m 755 "$instdir/bin/avastdwatch.sh" "$bindir/avastdwatch.sh"

    #installing the avast! daemon
    if [ ! -d $sbindir ]; then mkdir -p $sbindir ; fi
    install -m 755 "$instdir/sbin/avastd" "$sbindir/avastd"

    #installing manual pages
    if [ ! -d $mandir/man1 ]; then mkdir -p $mandir/man1 ; fi
    install -m 644 $instdir/man/man1/avastcmd.1 $mandir/man1/avastcmd.1
    install -m 644 $instdir/man/man1/avastlite.1 $mandir/man1/avastlite.1
    if [ ! -d $mandir/man5 ]; then mkdir -p $mandir/man5 ; fi
    install -m 644 $instdir/man/man5/avastd.conf.5 $mandir/man5/avastd.conf.5
    if [ ! -d $mandir/man8 ]; then mkdir -p $mandir/man8 ; fi
    install -m 644 $instdir/man/man8/avastd.8 $mandir/man8/avastd.8

    #installing documentation
    if [ ! -d $docdir/$packagename-$packagevers ]; then mkdir -p $docdir/$packagename-$packagevers ; fi
    install -m 644 "$instdir/AUTHORS" "$docdir/$packagename-$packagevers/AUTHORS"
    install -m 644 "$instdir/ChangeLog" "$docdir/$packagename-$packagevers/ChangeLog"
    install -m 644 "$instdir/INSTALL" "$docdir/$packagename-$packagevers/INSTALL"
    install -m 644 "$instdir/MANIFEST" "$docdir/$packagename-$packagevers/MANIFEST"
    install -m 644 "$instdir/README" "$docdir/$packagename-$packagevers/README"
    install -m 644 "$instdir/FAQ" "$docdir/$packagename-$packagevers/FAQ"
    if [ ! -d $docdir/$packagename-$packagevers/patches ]; then mkdir -p $docdir/$packagename-$packagevers/patches ; fi
    install -m 644 "$instdir/patches/HOWTO.samba-vscan" "$docdir/$packagename-$packagevers/patches/HOWTO.samba-vscan"
    install -m 644 "$instdir/patches/samba-vscan.patch" "$docdir/$packagename-$packagevers/patches/samba-vscan.patch"

    #install shared file
    if [ ! -d "$tempdir" ]; then mkdir -p -m 1777 "$tempdir" ; fi
    if [ ! -d "$logdir" ]; then mkdir -p -m 0755 "$logdir" ; fi
    if [ ! -d "$rundir" ]; then mkdir -p -m 0755 "$rundir" ; fi

    #installing etc file
    if [ ! -d $sysdir ]; then mkdir -p $sysdir ; fi
    if [ -f $sysdir/avastd.conf ]; then install -m 644 $instdir/etc/avastd.conf $sysdir/avastd.conf.example ;
    else install -m 644 $instdir/etc/avastd.conf $sysdir/avastd.conf ; fi

    case "${osstyle}" in
    rh)
	if [ ! -d /etc/init.d ]; then mkdir -p /etc/init.d ; fi
	install -m 755 $instdir/etc/init.d/avastd /etc/init.d/avastd
	chkconfig --add avastd
	#syconfig file
        if [ ! -d /etc/sysconfig ]; then mkdir -p /etc/sysconfig ; fi
	install -m 644 $instdir/etc/conf.d/avastd /etc/sysconfig/avastd
	;;
    gentoo)
	if [ ! -d /etc/init.d ]; then mkdir -p /etc/init.d ; fi
	install -m 755 $instdir/etc/init.d/avastd.gentoo /etc/init.d/avastd
	rc-update add avastd default
	#conf.d file
        if [ ! -d /etc/conf.d ]; then mkdir -p /etc/conf.d ; fi
	install -m 644 $instdir/etc/conf.d/avastd /etc/conf.d/avastd
	;;
    debian)
	if [ ! -d /etc/init.d ]; then mkdir -p /etc/init.d ; fi
	install -m 755 $instdir/etc/init.d/avastd /etc/init.d/avastd
	#default file
        if [ ! -d /etc/default ]; then mkdir -p /etc/default ; fi
	install -m 644 $instdir/etc/conf.d/avastd /etc/default/avastd
	if [ -x /etc/init.d/avastd ]
	    then
		update-rc.d avastd defaults >/dev/null
		if [ -x /usr/sbin/invoke-rc.d ]
		    then
			invoke-rc.d avastd restart
		    else
			/etc/init.d/avastd restart
		    fi
	    fi
	;;
    suse)
	if [ ! -d /etc/init.d ]; then mkdir -p /etc/init.d ; fi
	install -m 755 $instdir/etc/init.d/avastd /etc/init.d/avastd
	insserv /etc/init.d/avastd
	#rc.config.d file
	if [ -f /etc/rc.config ]; then
	        if [ ! -d /etc/rc.config.d ]; then mkdir -p /etc/rc.config.d ; fi
		install -m 644 $instdir/etc/conf.d/avastd /etc/rc.config.d/avastd.rc.config
	else
		if [ ! -d /etc/sysconfig ]; then mkdir -p /etc/sysconfig ; fi
		install -m 644 $instdir/etc/conf.d/avastd /etc/sysconfig/avastd
	fi
	;;
    lsb)
	if [ ! -d /etc/init.d ]; then mkdir -p /etc/init.d ; fi
	install -m 755 $instdir/etc/init.d/avastd /etc/init.d/avastd
	/usr/lib/lsb/install_initd /etc/init.d/avastd
	#rc.config.d file
        if [ ! -d /etc/rc.config.d ]; then mkdir -p /etc/rc.config.d ; fi
	install -m 644 $instdir/etc/conf.d/avastd /etc/rc.config.d/avastd.rc.config
	;;
    slackware)
	if [ ! -d /etc/rc.d ]; then mkdir -p /etc/rc.d ; fi
	install -m 755 $instdir/etc/init.d/avastd /etc/rc.d/rc.avastd
	#insserv /etc/init.d/avastd
	install -m 644 $instdir/etc/conf.d/avastd /etc/rc.d/avastd.rc.conf
	;;
    sysv)
	if [ ! -d /etc/init.d ]; then mkdir -p /etc/init.d ; fi
	install -m 755 $instdir/etc/init.d/avastd /etc/init.d/avastd
	if [ $? -ne 0 ]; then
	    echo "Please, install 'etc/init.d/avastd' startup script manualy."
	fi
	if [ ! -d /etc/default ]; then mkdir -p /etc/default ; fi
	install -m 644 $instdir/etc/conf.d/avastd /etc/default/avastd
	;;
    *)
	install -m 755 $instdir/etc/init.d/avastd /usr/local/etc/rc.d/avastd.sh
	if [ $? -ne 0 ]; then
	    echo "Please, install 'etc/init.d/avastd' startup script manualy."
	fi
	install -m 644 $instdir/etc/conf.d/avastd /usr/local/etc/avastd.rc
	;;
    esac

    #check paths in PATH and MANPATH environment variables
    bindir_acc=0
    sbindir_acc=0
    mandir_acc=0

    for x in `echo $PATH | sed 's/:/ /g'`
    do
	if [ "$x" = "$bindir" ]; then bindir_acc=1; fi
	if [ "$x" = "$sbindir" ]; then sbindir_acc=1; fi
    done
    for x in `echo $MANPATH | sed 's/:/ /g'` /usr/local/share/man /usr/local/man /usr/share/man
    do
	if [ "$x" = "$mandir" ]; then mandir_acc=1; fi
    done

    if [ $bindir_acc -eq 0 -a $bindir != "/usr/local/bin" ]; then
	rm /usr/local/bin/avastcmd >/dev/null 2>&1; ln -s $bindir/avastcmd /usr/local/bin/avastcmd
	rm /usr/local/bin/avastlite >/dev/null 2>&1; ln -s $bindir/avastlite /usr/local/bin/avastlite
	rm /usr/local/bin/avastdwatch.sh >/dev/null 2>&1; ln -s $bindir/avastdwatch.sh /usr/local/bin/avastdwatch.sh
    fi
    if [ $sbindir_acc -eq 0 -a $sbindir != "/usr/local/sbin" ]; then
	rm /usr/local/sbin/avastd >/dev/null 2>&1; ln -s $sbindir/avastd /usr/local/sbin/avastd
    fi
    if [ $mandir_acc -eq 0 ]; then
	sharedir="share"
	if [ ! `uname -s` = "Linux" ]; then sharedir="" ; fi
	rm /usr/local/$sharedir/man/man1/avastcmd.1 >/dev/null 2>&1; ln -s $mandir/man1/avastcmd.1 /usr/local/$sharedir/man/man1/avastcmd.1
	rm /usr/local/$sharedir/man/man1/avastlite.1 >/dev/null 2>&1; ln -s $mandir/man1/avastlite.1 /usr/local/$sharedir/man/man1/avastlite.1
	rm /usr/local/$sharedir/man/man5/avastd.conf.5 >/dev/null 2>&1; ln -s $mandir/man5/avastd.conf.5 /usr/local/$sharedir/man/man5/avastd.conf.5
	rm /usr/local/$sharedir/man/man8/avastd.8 >/dev/null 2>&1; ln -s $mandir/man8/avastd.8 /usr/local/$sharedir/man/man8/avastd.8
    fi

    #create avast4 groupname and username
    #if [ -z "`cat /etc/group | cut -f1 -d':'| grep avast4`" ]; then
    #	if [ $platform = "Linux" ]; then
    #	    groupadd -f avast4
    #	else
    #	    pw groupadd -n avast4
    #	fi
    #fi

    #if [ -z "`cat /etc/passwd | cut -f1 -d':' | grep avast4`" ]; then
    #	if [ $platform = "Linux" ]; then
    #	    useradd -g avast4 -c avast! -d /nonexistent -s /sbin/nologon avast4
    #	else
    #	    pw useradd -g avast4 -c avast -d /nonexistent -s /sbin/nologon -n avast4
    #	fi
    #fi

    echo ""
    echo "IMPORTANT NOTE: Assigning sections in avastd.conf to different users is"
    echo "a good idea for the system security, but note that since the engine 4.6.5"
    echo "(libavastengine-4.so.6.0.10) the shared memory usage scenario has changed."
    echo "Now, each user owns his full set of private SHM blocks and thus the SHM"
    echo "resource limits might be exhausted (count with ~16MB per user). In this"
    echo "case, increase the SHM limits using sysctl -w, /etc/system or /etc/rc."
    echo "Current SHM limits can be probed using the shmprobe binary which is"
    echo "a part of the engine installation package since the version 4.6.5."
    echo "Additional details about SHM adjusting (for different systems) can be"
    echo "found in the mkinstall.sh file in the engine installation package."

    sleep 1
    echo ""
    echo "$packagename installation completed succesfully."
    #echo "See instructions in the README file."
    echo ""
}

func_uninstall ()
{
    echo ""
    echo ""
    echo "Copyright(C) 2003-2010 ALWIL Software.  All rights reserved."
    echo ""
    echo "To uninstall 'avast!4', press ENTER."
    echo ""
    echo "To cancel the installation at any time, press Control-C."
    echo ""
    read cont < /dev/tty

    #check for previous library intallation
    func_docheck

    echo ""
    previnstall=0;
    if [ ! -z "$check_bin_avastcmddir" ] ; then echo "found installed $check_bin_avastcmddir/avastcmd file" ; previnstall=1 ; fi
    if [ ! -z "$check_bin_avastlitedir" ] ; then echo "found installed $check_bin_avastlitedir/avastlite file" ; previnstall=1 ;fi
    if [ ! -z "$check_bin_avastdwatchdir" ] ; then echo "found installed $check_bin_avastdwatchdir/avastdwatch.sh file" ; previnstall=1 ;fi
    if [ ! -z "$check_sbin_avastddir" ] ; then echo "found installed $check_sbin_avastddir/avastd file" ; previnstall=1 ;fi
    if [ ! -z "$check_man1_avastcmddir" ] ; then echo "found installed $check_man1_avastcmddir/avastcmd.1 file" ; previnstall=1 ;fi
    if [ ! -z "$check_man1_avastlitedir" ] ; then echo "found installed $check_man1_avastlitedir/avastcmd.1 file" ; previnstall=1 ;fi
    if [ ! -z "$check_man5_avastdconfdir" ] ; then echo "found installed $check_man5_avastdconfdir/avastd.conf.5 file" ; previnstall=1 ;fi
    if [ ! -z "$check_man8_avastddir" ] ; then echo "found installed $check_man8_avastddir/avastd.8 file" ; previnstall=1 ;fi

    if [ $previnstall -eq 1 ] ; then
	echo ""
        echo "Do you want to uninstall these files?"
	get_agreement
        if [ $? -eq 0 ] ; then
	    echo " "
    	    exit 1
	else
	    if [ ! -z "$check_bin_avastcmddir" ] ; then
		rm -f $check_installprefix/bin/avastcmd
		rm -f $check_bin_avastcmddir/avastcmd
	    fi
	    if [ ! -z "$check_bin_avastlitedir" ] ; then
		rm -f $check_installprefix/bin/avastlite
		rm -f $check_bin_avastlitedir/avastlite
	    fi
	    if [ ! -z "$check_bin_avastdwatchdir" ] ; then
		rm -f $check_installprefix/bin/avastdwatch.sh
		rm -f $check_bin_avastdwatchdir/avastdwatch.sh
	    fi
	    if [ ! -z "$check_sbin_avastddir" ] ; then
		rm -f $check_installprefix/sbin/avastd
		rm -f $check_sbin_avastddir/avastd
	    fi
	    if [ "$check_installprefix" != "/usr" ]&&[ "$check_installprefix" != "/usr/local" ]; then
		rmdir $check_installprefix/bin 2>/dev/null
		rmdir $check_installprefix/sbin 2>/dev/null
	    fi

	    #uninstall manual pages
	    if [ ! -z "$check_man1_avastcmddir" ] ; then
		rm -f $check_installprefix/share/man/man1/avastcmd.1
		rm -f $check_installprefix/man/man1/avastcmd.1
		rm -f $check_man1_avastcmddir/avastcmd.1
	    fi
	    if [ ! -z "$check_man1_avastlitedir" ] ; then
		rm -f $check_installprefix/share/man/man1/avastlite.1
		rm -f $check_installprefix/man/man1/avastlite.1
		rm -f $check_man1_avastlitedir/avastlite.1
	    fi
	    if [ ! -z "$check_man5_avastdconfdir" ] ; then
		rm -f $check_installprefix/share/man/man5/avastd.conf.5
		rm -f $check_installprefix/man/man5/avastd.conf.5
		rm -f $check_man5_avastdconfdir/avastd.conf.5
	    fi
	    if [ ! -z "$check_man8_avastddir" ] ; then
		rm -f $check_installprefix/share/man/man8/avastd.8
		rm -f $check_installprefix/man/man8/avastd.8
		rm -f $check_man8_avastddir/avastd.8
	    fi
	    if [ "$check_installprefix" != "/usr" ]&&[ "$check_installprefix" != "/usr/local" ]; then
		#remove directories
		rmdir $check_installprefix/share/man/man1 2>/dev/null
		rmdir $check_installprefix/share/man/man5 2>/dev/null
		rmdir $check_installprefix/share/man/man8 2>/dev/null
		rmdir $check_installprefix/share/man 2>/dev/null
	    fi

	    #uninstall program documentation
	    rm -f $check_installprefix/share/doc/$packagename-$packagevers/patches/*
	    rmdir $check_installprefix/share/doc/$packagename-$packagevers/patches 2>/dev/null
	    rm -f $check_installprefix/share/doc/$packagename-$packagevers/*
	    rmdir $check_installprefix/share/doc/$packagename-$packagevers 2>/dev/null
	    if [ "$check_installprefix" != "/usr" ]&&[ "$check_installprefix" != "/usr/local" ]; then
		rmdir $check_installprefix/share/doc 2>/dev/null
		rmdir $check_installprefix/share 2>/dev/null
		rmdir $check_installprefix 2>/dev/null
	    fi

	    case "${osstyle}" in
		rh)
			chkconfig --del avastd
			rm -f /etc/init.d/avastd
			;;
	        gentoo)
			rc-update del avastd
			rm -f /etc/init.d/avastd
			;;
		debian)
			rm -f /etc/init.d/rc.avastd
			update-rc.d avastd remove 2>/dev/null
			;;
	        suse)
			insserv -r /etc/init.d/avastd
			rm -f /etc/init.d/avastd
			;;
	        lsb)
			/usr/lib/lsb/remove_initd /etc/init.d/avastd
			rm -f /etc/init.d/avastd
			;;
		slackware)
			rm -f /etc/rc.d/rc.avastd
			;;
	        *)
			rm -f /usr/local/etc/rc.d/avastd.sh
			if [ $? -ne 0 ]; then
				echo "Please, uninstall 'etc/init.d/avastd' startup script manualy."
			fi
			;;
	    esac

	    echo ""
	    echo "Uninstallation complete!"
	    echo ""
	fi
    else
	echo ""
	echo "Could not find previously installed files !!!"
	echo " "
	exit 1
    fi
}

while test "$#" -gt 0
do
  arg="$1"
  shift

  case $arg in
      -*=*) optarg=`echo "$arg" | sed -e 's/[-_a-zA-Z0-9]*=//'` ;;
      *) optarg= ;;
  esac

  case "$arg" in
      --prefix=* | -p=* )
	  if [ $optarg = "/usr/local" ]; then sys_prefix=$optarg ; fi
	  usr_prefix=$optarg;

	  sysdir="$sys_prefix/etc"
	  bindir="$usr_prefix/bin"
	  sbindir="$usr_prefix/sbin"
	  docdir="$usr_prefix/share/doc"
	  mandir="$usr_prefix/share/man";
	  if [ "$usr_prefix" = "/usr/local" ] && [ ! `uname -s` = "Linux" ]; then
	      mandir="$usr_prefix/man";
          fi

	  #tempdir="$var_prefix/tmp/avast4"
	  #logdir="$var_prefix/lib/avast4/log"
	  ;;
      --uninstall | -u )
	  func_uninstall; exit 0;;
      --help | -h )
	  func_help; exit 0 ;;
      --version | -V | -v )
	  func_version; exit 0 ;;
  esac
done
func_install

exit 0
