#!/bin/sh
#
# Copyright (c) 2013, AVG Technologies CZ, s.r.o., www.avg.com
# Uninstall script for the AVG Anti-Virus for Linux/FreeBSD
#

INIT_SLINK_PATH=
YES_TO_ALL=0

# -*-Shell-script-*-
#
# functions.setup
#
# This is a script sourced by install.sh and setup.sh 
# containing common functions for these scripts.
#

#
# Read the value from configuration file and store it into the variable given in $2
#
read_from_conf()
{
	# mandatory parameters
	local FILE="$1"
	local RECORD_REF="$2"
	local KEY="$3"
	# optional parameters
	local DEFAULT_VALUE="$4"
	local DELIMITERS="${5:-#=}"
	local CASE_INSENSITIVE="$6"
	local RECORD=""

	if [ -f "$FILE" ]; then
		RECORD=$(sed -ne "s%^[[:space:]]*$KEY[[:space:]]*=[[:space:]]*\([^$DELIMITERS]\+\).*%\1%p$CASE_INSENSITIVE" $FILE)
	fi

	[ -z "$RECORD" ] && RECORD="$DEFAULT_VALUE"

	eval $RECORD_REF='$RECORD'
}

#
# Case insensitive variant read_from_conf
#
read_from_confi()
{
	read_from_conf "$1" "$2" "$3" "$4" "$5" "I"
}

#
# Replace or add the received KEY=VALUE into configuration file (replace also if #KEY= found)
#
write_to_conf()
{
	# mandatory parameters
	local FILE="$1"
	local KEY="$2"
	local VALUE="$3"
	# optional parameters
	local CASE_INSENSITIVE="$4"

	if [ -f "$FILE" ]; then
		sed -i.bck -e "s%^[#[:space:]]*$KEY[[:space:]]*=.*%$KEY=$VALUE%$CASE_INSENSITIVE" $FILE && rm $FILE.bck
	fi

	grep "$KEY=$VALUE" $FILE >/dev/null 2>&1 || echo "$KEY=$VALUE" >> $FILE
}

#
# Case insensitive variant write_to_conf
#
write_to_confi()
{
	write_to_conf "$1" "$2" "$3" "I"
}

#
# Print $QUESTIONS_ALIGN-$1 spaces (only print positive number, and if QUESTIONS_ALIGN defined)
#
ralign()
{
	local QUESTION_LEN=$1
	local FILL_LEN=$(($QUESTIONS_ALIGN-$QUESTION_LEN))

	[ $FILL_LEN -gt 0 ] && printf "%${FILL_LEN}s"
}
         

#
# QUESTIONS
#
ask_yesorno_question()
{
	QUESTION="$1"

	if [ $YES_TO_ALL -eq 0 ]
	then
    	while echo -n "$QUESTION $(ralign ${#QUESTION})(yes/no): "
    	do
			read ANSWER
			case $ANSWER in
				[yY][eE][sS]*)
	    			return 1
	    			;;
				[nN][oO]*)
	    			return 0
	    			;;
				*)
	    			echo "Please answer yes or no"
	    			;;
			esac
    	done
	else
		return 1
	fi
}

ask_Yorn_question()
{
	QUESTION="$1"
	
	if [ $YES_TO_ALL -eq 0 ]
	then
    	while echo -n "$QUESTION $(ralign ${#QUESTION})(Y/n): "
    	do
			read ANSWER
			case $ANSWER in
				"")
	    			return 1
	    			;;
				[yY]*)
	    			return 1
	    			;;
				[nN]*)
	    			return 0
	    			;;
				*)
	    			echo "Please answer y or n"
	    			;;
			esac
    	done
	else
		return 1;
	fi
}

ask_yorN_question()
{
	QUESTION="$1"

	if [ $YES_TO_ALL -eq 0 ]
	then
    	while echo -n "$QUESTION $(ralign ${#QUESTION})(y/N): "
    	do
			read ANSWER
			case $ANSWER in
				"")
	    			return 0
	    			;;
				[yY]*)
	    			return 1
	    			;;
				[nN]*)
	    			return 0
	    			;;
				*)
	    			echo "Please answer y or n"
	    			;;
			esac
    	done
	else
		return 0;
	fi
}

#
# Ask $1 question and store a nonzero answer into the variable given in $2
#
ask_default_answer_question()
{
	local QUESTION="$1"
	local ANSWER_REF="$2"
	local ANSWER=""

	if [ $YES_TO_ALL -eq 0 ] ; then
		eval echo -n "'$QUESTION $(ralign ${#QUESTION})'[\$$ANSWER_REF]: "
		read ANSWER
		[ -n "$ANSWER" ] && eval $ANSWER_REF='$ANSWER'
	fi
}

#
# Store the number of the selected option into the variable given in $2
#
ask_option_question()
{
	if [ $YES_TO_ALL -eq 0 ]; then
		local QUESTION="$1"
		local ANSWER_REF="$2"
		local QUESTION_NUMBER=0
		local ANSWER=0
		local PROMPT="? "

		echo "$QUESTION:"
		while [ -n "$3" ]; do
			QUESTION_NUMBER=$(($QUESTION_NUMBER + 1))
			echo " $QUESTION_NUMBER) $3"
			shift
		done

		eval local ANSWER_DEF=\$$ANSWER_REF
		[ -n "$ANSWER_DEF" ] && PROMPT="[$ANSWER_DEF] $PROMPT"

		while [ $ANSWER -lt 1  -o  $ANSWER -gt $QUESTION_NUMBER ] ; do
			echo -n "$PROMPT"
			read ANSWER
			[ -z "$ANSWER" ] && ANSWER=$ANSWER_DEF
			echo $ANSWER | grep "^[0-9]\+$" >/dev/null || ANSWER=0
		done

		eval $ANSWER_REF='$ANSWER'
	fi
}


#
# PRINT MESSAGES
#
abort()
{
	while [ -n "$1" ]; do 
		echo "$1"
		shift
	done

	exit 1
}

warning()
{
	REASON="$1"
	echo "warning: $REASON"
}

print_yes_no()
{
	[ $1 -eq 1 ] && echo "yes" || echo "no"
}
ANSWER=""
ABORT_TEXT="Uninstallation aborted"
TAIL_TEXT="AVG Anti-Virus for Linux/FreeBSD successfully removed"
NOTE_TEXT="
Note: All the AVG Anti-Virus files will be removed including the configuration
      If you want to keep this files backup them prior the uninstallation
      process.
"

remove_file()
{
	FILE_PATH="$(/bin/ls $@)"

    for f in $FILE_PATH;
	do
		if [ -f $f -o -h $f ]
    	then
        	echo "Removing file '$f'..."
        	rm -f "$f"
    	else
			warning "File '$f' doesn't exist!"
    	fi

    	if [ $? -ne 0 ]
    	then
			warning "Can't remove file '$f'!"
    	fi
	done
}

remove_dirs()
{
    DIRS="$1"
	
	for i in $DIRS;
	do
	echo "Removing dir '$i'..."

		if [ -d $i ]
		then
			rmdir $i
			if [ $? -ne 0 ]
			then
				ask_yorN_question "Removing of directory failed. Do you want to erase its content?"
				if [ $? -eq 1 ]
				then
					rm -f $i/*
			
					rmdir $i
					if [ $? -ne 0 ]
					then
						warning "Can't remove directory '$i'!"
					fi
				else
					warning "Can't remove directory '$i'!"
				fi
			fi
		fi
	done
}

stop_server()
{    
    STATUS=`ps axo comm | grep ^avgd$`
    if [ -n "$STATUS" ]
    then
	   ask_Yorn_question "There is running avgd daemon. Do you want to stop it first?"
	   if [ $? -eq 1 ] 
		then 
			if [ -n "$INIT_SLINK_PATH" ]
			then
				$INIT_SLINK_PATH stop
			else
				avgctl --stop >/dev/null 2>&1
			fi
		fi
    fi
}

clear
echo "================================================="
echo " AVG Anti-Virus for Linux/FreeBSD uninstallation "
echo "================================================="
echo

# check_root
if [ $(id -u) -ne 0 ]
then
    abort "Try to run this as root.";
	
    exit 1;
fi

echo "$NOTE_TEXT"
ask_yesorno_question "Do you want to continue?"
if [ $? -eq 0 ]
then
    abort
fi

stop_server
echo "Unregistering 'avgd' service ..."
echo "Please unregister the 'avgd' service initscript from startup and runlevels."
echo "Uninstalling 'avgd' service initscripts..."
echo "Automatic uninstallation of initscripts for your platform/distribution is not supported."
echo "Please remove the symbolic link to file /opt/avg/av/etc/init.d/avgd.all created manually after installation."
remove_file '/opt/avg/av/lib/libavgcfg.so'
remove_file '/opt/avg/av/lib/libavgcomm.so'
remove_file '/opt/avg/av/lib/libstdc++.so.6'
remove_file '/opt/avg/av/lib/libdialog.so'
remove_file '/opt/avg/av/lib/libavgcore.so'
remove_file '/opt/avg/av/lib/libavgcorelite.so'
remove_file '/opt/avg/av/lib/libavgupd.so'
remove_file '/opt/avg/av/lib/libavglog.so'
remove_file '/opt/avg/av/lib/libavgsys.so'
remove_file '/opt/avg/av/lib/libavgavidcli.so'
remove_file '/opt/avg/av/lib/libgcc_s.so.1'
remove_file '/opt/avg/av/lib/libavgaspam.so'
remove_file '/opt/avg/av/lib/libdazukofs.so'
remove_file '/opt/avg/av/lib/libncurses.so.5'
remove_file '/opt/avg/av/lib/libavglng.so'
remove_file '/opt/avg/av/lib/libavgcert.so'
remove_file '/opt/avg/av/bin/avgscan'
remove_file '/opt/avg/av/bin/avgspamd'
remove_file '/opt/avg/av/bin/avgscand'
remove_file '/opt/avg/av/bin/avgevtlog'
remove_file '/opt/avg/av/bin/avgctl'
remove_file '/opt/avg/av/bin/avgvvctl'
remove_file '/opt/avg/av/bin/avgoad'
remove_file '/opt/avg/av/bin/avgdump'
remove_file '/opt/avg/av/bin/avgupd'
remove_file '/opt/avg/av/bin/avgdiag'
remove_file '/opt/avg/av/bin/avgsetup'
remove_file '/opt/avg/av/bin/avgwrapper.sh'
remove_file '/opt/avg/av/bin/avgavid'
remove_file '/opt/avg/av/bin/avgupdate'
remove_file '/opt/avg/av/bin/avgcfgctl'
remove_file '/opt/avg/av/bin/avgtcpd'
remove_file '/opt/avg/av/bin/avgsched'
remove_file '/opt/avg/av/bin/avgd'
remove_file '/opt/avg/av/doc/README.GNUkFreeBSD'
remove_file '/opt/avg/av/doc/licenses/tinyxml.txt'
remove_file '/opt/avg/av/doc/licenses/minizip.txt'
remove_file '/opt/avg/av/doc/licenses/curl.txt'
remove_file '/opt/avg/av/doc/licenses/ace.txt'
remove_file '/opt/avg/av/doc/licenses/ncurses.txt'
remove_file '/opt/avg/av/doc/licenses/bsdiff.txt'
remove_file '/opt/avg/av/doc/licenses/milter.txt'
remove_file '/opt/avg/av/doc/licenses/dazukofs.txt'
remove_file '/opt/avg/av/doc/licenses/carp.html'
remove_file '/opt/avg/av/doc/licenses/7zip.txt'
remove_file '/opt/avg/av/doc/licenses/unrar.txt'
remove_file '/opt/avg/av/doc/licenses/arabica.txt'
remove_file '/opt/avg/av/doc/licenses/expat.txt'
remove_file '/opt/avg/av/doc/licenses/openssl_license.html'
remove_file '/opt/avg/av/doc/licenses/md4_md5_license.txt'
remove_file '/opt/avg/av/doc/licenses/imagemagick.txt'
remove_file '/opt/avg/av/doc/licenses/xalan_xerces.txt'
remove_file '/opt/avg/av/doc/licenses/sasl.txt'
remove_file '/opt/avg/av/doc/licenses/lua.txt'
remove_file '/opt/avg/av/doc/licenses/bzip.txt'
remove_file '/opt/avg/av/doc/licenses/boost.txt'
remove_file '/opt/avg/av/doc/licenses/dialog.txt'
remove_file '/opt/avg/av/doc/licenses/infozip.txt'
remove_file '/opt/avg/av/doc/licenses/cryptopp.txt'
remove_file '/opt/avg/av/doc/licenses/zlib.txt'
remove_file '/opt/avg/av/doc/licenses/untar.txt'
remove_file '/opt/avg/av/doc/README.selinux'
remove_file '/opt/avg/av/doc/README.amavis'
remove_file '/opt/avg/av/doc/README'
remove_file '/opt/avg/av/doc/README.postfix'
remove_file '/opt/avg/av/doc/README.samba'
remove_file '/opt/avg/av/doc/license_us.txt'
remove_file '/opt/avg/av/doc/README.avgdiag'
remove_file '/opt/avg/av/doc/README.oad'
remove_file '/opt/avg/av/doc/README.sendmail'
remove_file '/opt/avg/av/doc/README.exim'
remove_file '/opt/avg/av/doc/README.antispam'
remove_file '/opt/avg/av/doc/README.qmail'
remove_file '/opt/avg/av/doc/README.qmailscanner'
remove_file '/opt/avg/av/doc/ChangeLog'
remove_file '/opt/avg/av/etc/avg.conf'
remove_file '/opt/avg/av/etc/init.d/avgd.gentoo'
remove_file '/opt/avg/av/etc/init.d/functions.suse'
remove_file '/opt/avg/av/etc/init.d/functions.gentoo'
remove_file '/opt/avg/av/etc/init.d/avgdinit.conf'
remove_file '/opt/avg/av/etc/init.d/functions.rh'
remove_file '/opt/avg/av/etc/init.d/functions.mdk'
remove_file '/opt/avg/av/etc/init.d/avgd.all'
remove_file '/opt/avg/av/etc/init.d/functions.ubuntu'
remove_file '/opt/avg/av/etc/init.d/functions.oad'
remove_file '/opt/avg/av/etc/init.d/functions.tcpd'
remove_file '/opt/avg/av/etc/init.d/functions.freebsd'
remove_file '/opt/avg/av/etc/init.d/functions.deployment'
remove_file '/opt/avg/av/etc/init.d/functions.deb'
remove_file '/opt/avg/av/etc/init.d/functions.diag'
remove_file '/opt/avg/av/etc/init.d/functions.common'
remove_file '/opt/avg/av/etc/init.d/functions.slack'
remove_file '/opt/avg/av/etc/init.d/functions.config'
remove_file '/opt/avg/av/etc/init.d/functions.setup'
remove_file '/opt/avg/av/cfg/avid.ini'
remove_file '/opt/avg/av/cfg/sched.ini'
remove_file '/opt/avg/av/cfg/dfncfg.dat'
remove_file '/opt/avg/av/cfg/wd.ini'
remove_file '/opt/avg/av/cfg/tcpd.ini'
remove_file '/opt/avg/av/cfg/pub.ini'
remove_file '/opt/avg/av/cfg/vv.ini'
remove_file '/opt/avg/av/cfg/upd.ini'
remove_file '/opt/avg/av/cfg/scand.ini'
remove_file '/opt/avg/av/cfg/oad.ini'
remove_file '/opt/avg/av/cfg/updatecomps.cfg'
remove_file '/opt/avg/av/cfg/priv.ini'
remove_file '/opt/avg/av/cfg/dump.ini'
remove_file '/opt/avg/av/cfg/spam.ini'
remove_file '/opt/avg/av/cfg/diagcfg.xml'
remove_file '/opt/avg/av/man/man1/avgtcpd.1.gz'
remove_file '/opt/avg/av/man/man1/avgavid.1.gz'
remove_file '/opt/avg/av/man/man1/avgd.1.gz'
remove_file '/opt/avg/av/man/man1/avgscan.1.gz'
remove_file '/opt/avg/av/man/man1/avgsched.1.gz'
remove_file '/opt/avg/av/man/man1/avgvvctl.1.gz'
remove_file '/opt/avg/av/man/man1/avgcfgctl.1.gz'
remove_file '/opt/avg/av/man/man1/avgoad.1.gz'
remove_file '/opt/avg/av/man/man1/avgupd.1.gz'
remove_file '/opt/avg/av/man/man1/avgspamd.1.gz'
remove_file '/opt/avg/av/man/man1/avgupdate.1.gz'
remove_file '/opt/avg/av/man/man1/avgscand.1.gz'
remove_file '/opt/avg/av/man/man1/avgctl.1.gz'
remove_file '/opt/avg/av/man/man1/avgdump.1.gz'
remove_file '/opt/avg/av/man/man1/avgevtlog.1.gz'
remove_file '/opt/avg/av/var/data/avg.snu'
remove_file '/opt/avg/av/var/data/incavi.avm'
remove_file '/opt/avg/av/var/data/avg8us.lng'
remove_file '/opt/avg/av/var/data/avg_gpg_key.pub'
remove_file '/usr/bin/avgcfgctl'
remove_file '/usr/bin/avgupdate'
remove_file '/usr/bin/avgsetup'
remove_file '/usr/bin/avgdiag'
remove_file '/usr/bin/avgdump'
remove_file '/usr/bin/avgvvctl'
remove_file '/usr/bin/avgctl'
remove_file '/usr/bin/avgevtlog'
remove_file '/usr/bin/avgscan'
remove_file '/usr/share/man/man1/avgevtlog.1.gz'
remove_file '/usr/share/man/man1/avgdump.1.gz'
remove_file '/usr/share/man/man1/avgctl.1.gz'
remove_file '/usr/share/man/man1/avgscand.1.gz'
remove_file '/usr/share/man/man1/avgupdate.1.gz'
remove_file '/usr/share/man/man1/avgspamd.1.gz'
remove_file '/usr/share/man/man1/avgupd.1.gz'
remove_file '/usr/share/man/man1/avgoad.1.gz'
remove_file '/usr/share/man/man1/avgcfgctl.1.gz'
remove_file '/usr/share/man/man1/avgvvctl.1.gz'
remove_file '/usr/share/man/man1/avgsched.1.gz'
remove_file '/usr/share/man/man1/avgscan.1.gz'
remove_file '/usr/share/man/man1/avgd.1.gz'
remove_file '/usr/share/man/man1/avgavid.1.gz'
remove_file '/usr/share/man/man1/avgtcpd.1.gz'
remove_file '/etc/avg.conf'
remove_file /opt/avg/av/bin/uninstall.sh

# Remove files created after installation
rm -rf /opt/avg/av/update/*
rm -rf /opt/avg/av/log/*
rm -f  /opt/avg/av/cfg/*
rm -f  /opt/avg/av/var/run/*
rm -f  /opt/avg/av/var/data/*
rm -f  /opt/avg/av/var/antispam/.l*
rm -f  /opt/avg/av/var/antispam/*

# Remove created dirs
remove_dirs "/opt/avg/av/var/data /opt/avg/av/var/run /opt/avg/av/var /opt/avg/av/man/man1 /opt/avg/av/man /opt/avg/av/cfg /opt/avg/av/etc/init.d /opt/avg/av/etc /opt/avg/av/update /opt/avg/av/log /opt/avg/av/doc/licenses /opt/avg/av/doc /opt/avg/av/bin /opt/avg/av/lib /opt/avg/av "

echo
echo "$TAIL_TEXT"
